@@ -16,7 +16,7 @@
 #ifndef _K3B_DATAMODE_WIDGET_H_
 #define _K3B_DATAMODE_WIDGET_H_
 
-#include <KConfigCore/KConfigGroup>
+#include <KConfigGroup>
 
 #include <QComboBox>
 
@@ -28,7 +28,7 @@ class DataModeWidget : public QComboBox
 
  public:
   explicit DataModeWidget( QWidget* parent = 0 );
-  ~DataModeWidget();
+  ~DataModeWidget() override;
 
   /**
    * returnes K3b::DataMode
