@@ -18,7 +18,7 @@
 
 #include "k3bglobals.h"
 
-#include <KConfigCore/KConfig>
+#include <KConfig>
 #include <KLocalizedString>
 
 #include <QToolTip>
